#include "mbed.h"

Serial pc(USBTX, USBRX); // tx, rx

DigitalOut led1(LED1);
DigitalOut led2(LED2);
DigitalOut led3(LED3);
DigitalOut led4(LED4);


DigitalOut pinReset(p16);
DigitalOut pinSleep(p17);
DigitalOut pinStep(p18);
DigitalOut pinDir(p20);

// Control of the stepper motor with Ticker and Timeout
Ticker tickerStepper;
Timeout timeoutStepper;

// Rest the STEP pin
void StepperFall()
{
   pinStep = 0;
}

// Move the motor one step
void StepperRise()
{
    pinStep = 1;
    timeoutStepper.attach_us(
                            &StepperFall, // void(*fptr)(void)
                            2   // float t
                            );
}
    
// Activate the stepper motor
// at a constant speed
void Stepper_On(
                bool bForward = true
                )
{
    int nPPS = 1200; 
    float fRPM = nPPS / 200.f;
    float fFrequency_Hz = 1.f * nPPS;
    float fPeriod_s = 1.0/fFrequency_Hz;
    pinDir = bForward;
    tickerStepper.attach(
                        &StepperRise, // void(*fptr)(void)
                        fPeriod_s   // float t
                        );    
}

// Deactivate the motor
void Stepper_Off()
{
  tickerStepper.detach();  
}

int main() 
{
    led1 = 0; led2 = 0; led3 = 0; led4 = 0;
    pc.baud(921600);
    pinStep = 0;    // Stopped
    pinDir = 1;     // Forward

    pc.printf("Starting....\r\n");
    
    while(1)
        {
        // Activate the stepper motor for 5 s
        // at a constant speed
        Stepper_On( 
                    // bool bForward = true
                    );
        led1 = 1; wait(5);
        
        // Stop the motor for 5s
        Stepper_Off();
        led1 = 0; wait(5);
        
        // Activate the stepper motor for 5 s
        // at a constant speed (reverse)
        Stepper_On( 
                    false // bool bForward = true
                    );
        led2 = 1; wait(5);
        
        // Stop the motor for 5s
        Stepper_Off();
        led2 = 0; wait(5);
        }
}
